#!/bin/bash

COMPAT_MAJOR=("28")
COMPAT_MINOR=("2.0" "2.1")

COMPAT_PROFILES=("astro-mpcie"
                 "astro-mpcie-tx2i"
                 "astro-usb3"
                 "astro-usb3-tx2i"
                 "astro-revG+"
                 "astro-revG+-tx2i"
                 "elroy-mpcie"
                 "elroy-mpcie-tx2i"
                 "elroy-usb3"
                 "elroy-usb3-tx2i"
                 "elroy-revF+"
                 "elroy-refF+-tx2i"
                 "orbitty"
                 "orbitty-tx2i"
                 "rosie"
                 "rosie-tx2i"
                 "rudi-mpcie"
                 "rudi-mpcie-tx2i"
                 "rudi-usb3"
                 "rudi-usb3-tx2i"
                 "rudi"
                 "rudi-tx2i"
                 "sprocket"
                 "sprocket-imx274"
                 "sprocket-imx274-tx2i"
                 "sprocket-imx185"
                 "sprocket-imx185-tx2i"
                 "spacely-base"
                 "spacely-base-tx2i"
                 "spacely-imx185-6cam"
                 "spacely-imx185-6cam-tx2i"
                 "spacely-imx185-3cam"
                 "spacely-imx185-3cam-tx2i"
                 "spacely-imx274-6cam"
                 "spacely-imx274-6cam-tx2i"
                 "spacely-imx274-3cam"
                 "spacely-imx274-3cam-tx2i"
                 "cogswell"
                 "cogswell-tx2i"
                 "vpg003-base"
                 "vpg003-base-tx2i"
                 "vpg003-imx185-3cam"
                 "vpg003-imx185-3cam-tx2i"
                 "vpg003-imx274-3cam"
                 "vpg003-imx274-3cam-tx2i")

COMPAT_JETSON=("TX2" "TX2i")

CTI_L4T_VER="V121"


#utility functions
chkroot(){

    if [ $EUID -ne 0 ]
    then
        echo "Please run as sudo or root"
        exit 1
    fi
}

chkhost(){

    if [ $( uname -i | grep -c x86) -lt 1 ]; then
        echo "This version of the CTI-L4T BSP must be installed on the x86 Host system"
        exit 1
    fi

}

#check if bsp installed in the correct folder on host machine
chkfolder(){
    
    if [ $(basename $(dirname $(pwd))) != "Linux_for_Tegra" ] || [ $(basename $(pwd)) != "CTI-L4T" ]; then
        echo "This BSP should be extracted in the Linux_for_Tegra_tx2 directory"
        echo "of your Jetpack install. This install script  must be run from the"
        echo "Linux_for_Tegra_tx2/CTI-L4T directory"
        exit 2
    fi

}


install_dtb(){

    cp ./kernel/dtb/* ../kernel/dtb/

}

install_kernel(){

    cp ./kernel/*Image ../kernel/
    cp ./kernel/kernel_supplements.tbz2 ../kernel/
}

#install_bl(){

#    cp bl/BCT/* ../bootloader/t186ref/BCT
#   cp bl/cfg/* ../bootloader/t186ref/cfg
    
#    cp -r bl/cti/ ../bootloader/t186ref/ 

#}

install_ver_file(){

    if [ ! -d "../rootfs/etc/cti" ]; then
        mkdir ../rootfs/etc/cti
    fi  

    echo $CTI_L4T_VER > ../rootfs/etc/cti/CTI-L4T.version 

}

print_versions(){

    echo "Supported Version Information"
    echo "  CTI-L4T Board Support Package Version:" $CTI_L4T_VER

    echo "  Supported CTI Products (profiles): "
    for i in ${COMPAT_PROFILES[@]}; do
        echo "    " $i
    done

    echo "  Supported Linux for Tegra Release Versions: "
    for j in ${COMPAT_MINOR[@]}; do
        echo "    " $COMPAT_MAJOR"."$j
    done

    echo "  Supported Nvidia Jetson Module Hardware: "
    for k in ${COMPAT_JETSON[@]}; do
        echo "    " $k
    done

}

#help functions 

usage(){
    echo -e "  Usage: ./install.sh "
    echo -e "  Before installing this BSP, please read the included readme.txt"
    echo -e "  To switch between different products, the TX2 will need to be re-flashed"
    echo -e "  For the TX2i, use the *-tx2i.conf profiles"
    echo -e "  Below are the compatible L4T versions and board profiles:\n"

    print_versions
}


#start
usage

chkroot

chkfolder

tar -pxzf resources.tgz

#install CTI-flash
cp cti-flash.sh ..
chmod +x ../cti-flash.sh

#install .conf files into Linux_for_Tegra_tx2 

cp conf/* ..

install_dtb

#install_bl

install_kernel

install_ver_file



pushd ..

./apply_binaries.sh

popd

# ensure the files finish copying 
sync

echo "CTI-L4T-$CTI_L4T_VER Installed!"
